#
# spec file for package python-mwclient
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-mwclient
Version:        0.11.0
Release:        1.2
Summary:        MediaWiki API client
License:        MIT
URL:            https://github.com/mwclient/mwclient
Source:         https://files.pythonhosted.org/packages/source/m/mwclient/mwclient-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module requests-oauthlib}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module responses >= 0.3.0}
BuildRequires:  %{python_module responses}
BuildRequires:  %{python_module wheel}
# /SECTION
BuildRequires:  fdupes
Requires:       python-requests-oauthlib
BuildArch:      noarch
%python_subpackages

%description
MediaWiki API client

%prep
%autosetup -p1 -n mwclient-%{version}

sed -i -e '/^addopts/d' setup.cfg

%build
%pyproject_wheel

%install
%pyproject_install --ignore-installed
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.md
%license LICENSE.md
%{python_sitelib}/mwclient-%{version}*-info
%{python_sitelib}/mwclient

%changelog
* Wed Feb 12 2025 Markéta Machová <mmachova@suse.com>
- six is actually not needed anymore
* Wed Feb 12 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.11.0
  * The Site.writeapi attribute is removed. It has been hardcoded to
    True and deprecated in upstream mediawiki since 1.32, so code that
    uses it isn't doing anything useful.
  * The limit argument to various methods and generators is deprecated.
    Its name is misleading: it does not limit the total number of items
    returned, but sets the chunk size in which items are retrieved from
    the API. It is replaced by two other arguments: api_chunk_size does
    the same thing as limit but is more accurately named, and max_items
    does what limit sounds like it should do (caps the number of items
    that will be returned). limit still works, but will generate a
    deprecation warning.
  * The reqs argument to Site.__init__ was renamed to connection_options,
    which is a clearer name. The old name still works but will generate a
    deprecation warning.
  * Support for the clientlogin login method is added. See upstream documentation.
  * A new Site.patrol method has been added, to patrol a page or revision.
  * Support for Python 3.5 and earlier has been dropped. These versions of
    Python are obsolete and not used in any significant supported operating
    system.
- Add python-pytest-cov to BuildRequires
- Drop demock.patch, fixed upstream
- Update Github project page in URL field
- Switch package to modern Python Stack on SLE-15
  * Use Python 3.11 on SLE-15 by default
  * Drop support for older Python versions
* Sat Jul  2 2022 Matej Cepl <mcepl@suse.com>
- Initial packaging effort for python-mwclient 0.10.1.
- Add demock.patch removing dependency on the external mock
  module (gh#mwclient/mwclient#276).
